# Documentation

## rsmime

Python package for signing and verifying S/MIME messages

<a href="https://pypi.org/project/rsmime/">![PyPI](https://img.shields.io/pypi/v/rsmime?color=gr&style=for-the-badge)</a>

## API Reference

::: rsmime.Rsmime
::: rsmime.exceptions
